# salahhemdan

مكتبة لتحميل وسائط من كل مواقع سوشيال ميديا 

تدعم الفيديوهات والصور والصوتيات

تم البرمجة بواسطة المبرمج صلاح حمدان

## التثبيت
```bash
pip install salahhemdan
```

## الاستخدام
```python
from salahhemdan import download_media

data = download_media("yourlink") #رابط المراد تحميله
print(data)
```